import pytest
from pathlib import Path


# conftest.py
def pytest_collection_modifyitems(items):
    """Modifies test items in place to ensure plugin tests run in a specific order."""
    sorted_tests = []
    interference_tests = []
    plugin_tests = []  # push these to the back
    native_plugin_tests = []

    for test in items:
        if "plugin_pattern" in test.module.__name__:
            plugin_tests.append(test)
        elif "native_plugin" in test.module.__name__:
            native_plugin_tests.append(test)
        elif "test_interference" in test.module.__name__:
            interference_tests.append(test)
        else:
            sorted_tests.append(test)

    items[:] = [
        *sorted_tests,
        *plugin_tests,
        *native_plugin_tests,
        *interference_tests,
    ]


@pytest.hookimpl(tryfirst=True, hookwrapper=True)
def pytest_runtest_makereport(item, call):
    log_file = Path(__file__).parent / "tests.log"
    outcome = yield
    report = outcome.get_result()
    if report.when == "call" and report.outcome == "passed":
        if log_file.exists():
            with open(log_file, "a") as log_file:
                log_file.write(f"{item.nodeid}\n")



import typing as t

from typer import Argument, Option

from django_typer.management import Typer
from django_typer.utils import model_parser_completer
from tests.apps.examples.polls.models import Question as Poll

app = Typer(help="Closes the specified poll for voting")


@app.command()
def handle(
    self,
    polls: t.Annotated[
        t.List[Poll],
        Argument(**model_parser_completer(Poll, help_field="question_text")),
    ],
    delete: t.Annotated[
        bool, Option(help="Delete poll instead of closing it.")
    ] = False,
):
    for poll in polls:
        poll.opened = False
        poll.save()
        self.stdout.write(
            self.style.SUCCESS(f'Successfully closed poll "{poll.id}"')
        )
        if delete:
            poll.delete()



import os
import sys
from django import VERSION
from packaging.version import parse as parse_version


def test():
    # verify that the environment is set up correctly - this is used in CI to make
    # sure we're testing against the dependencies we think we are

    expected_python = os.environ["TEST_PYTHON_VERSION"]
    expected_django = os.environ["TEST_DJANGO_VERSION"]

    expected_python = parse_version(expected_python)
    assert sys.version_info[:2] == (expected_python.major, expected_python.minor), (
        f"Python Version Mismatch: {sys.version_info[:2]} != {expected_python}"
    )

    dj_actual = VERSION[:2]
    expected_django = parse_version(expected_django)
    dj_expected = (expected_django.major, expected_django.minor)
    assert dj_actual == dj_expected, (
        f"Django Version Mismatch: {dj_actual} != {expected_django}"
    )
